import{S as p,i as g,s as $,f as _,b as d,c as h,d as A,N as v,O as k,P as T,v as f,w as u,e as w,k as E,y as N,z as y,A as z,Q as B,J as D,Z as I,_ as J,R as C,q as M,u as O,x as P,E as Q}from"./index.f808f2eb.js";import{a as R}from"./Tabs.364a6e4d.js";function b(n){let s,l,e;const t=n[5].default,a=C(t,n,n[4],null);return{c(){s=_("div"),l=_("div"),a&&a.c(),d(l,"class","flex flex-col gr-gap gr-form-gap relative col overflow-auto flex-1"),d(s,"class","tabitem p-2 border-2 border-t-0 border-gray-200 relative flex")},m(o,r){h(o,s,r),A(s,l),a&&a.m(l,null),e=!0},p(o,r){a&&a.p&&(!e||r&16)&&v(a,t,o,o[4],e?T(t,o[4],r,null):k(o[4]),null)},i(o){e||(f(a,o),e=!0)},o(o){u(a,o),e=!1},d(o){o&&w(s),a&&a.d(o)}}}function Z(n){let s,l,e=n[0]===n[1]&&b(n);return{c(){e&&e.c(),s=E()},m(t,a){e&&e.m(t,a),h(t,s,a),l=!0},p(t,[a]){t[0]===t[1]?e?(e.p(t,a),a&1&&f(e,1)):(e=b(t),e.c(),f(e,1),e.m(s.parentNode,s)):e&&(N(),u(e,1,1,()=>{e=null}),y())},i(t){l||(f(e),l=!0)},o(t){u(e),l=!1},d(t){e&&e.d(t),t&&w(s)}}}function j(n,s,l){let e,{$$slots:t={},$$scope:a}=s,{name:o}=s;const r=z(),c={},{register_tab:S,unregister_tab:q,selected_tab:m}=B(R);return D(n,m,i=>l(0,e=i)),S({name:o,id:c}),I(()=>()=>q({name:o,id:c})),n.$$set=i=>{"name"in i&&l(3,o=i.name),"$$scope"in i&&l(4,a=i.$$scope)},n.$$.update=()=>{n.$$.dirty&1&&e===c&&J().then(()=>r("select"))},[e,c,m,o,a,t]}class F extends p{constructor(s){super(),g(this,s,j,Z,$,{name:3})}}function G(n){let s;const l=n[1].default,e=C(l,n,n[3],null);return{c(){e&&e.c()},m(t,a){e&&e.m(t,a),s=!0},p(t,a){e&&e.p&&(!s||a&8)&&v(e,l,t,t[3],s?T(l,t[3],a,null):k(t[3]),null)},i(t){s||(f(e,t),s=!0)},o(t){u(e,t),s=!1},d(t){e&&e.d(t)}}}function H(n){let s,l;return s=new F({props:{name:n[0],$$slots:{default:[G]},$$scope:{ctx:n}}}),s.$on("select",n[2]),{c(){M(s.$$.fragment)},m(e,t){O(s,e,t),l=!0},p(e,[t]){const a={};t&1&&(a.name=e[0]),t&8&&(a.$$scope={dirty:t,ctx:e}),s.$set(a)},i(e){l||(f(s.$$.fragment,e),l=!0)},o(e){u(s.$$.fragment,e),l=!1},d(e){P(s,e)}}}function K(n,s,l){let{$$slots:e={},$$scope:t}=s,{label:a}=s;function o(r){Q.call(this,n,r)}return n.$$set=r=>{"label"in r&&l(0,a=r.label),"$$scope"in r&&l(3,t=r.$$scope)},[a,e,o,t]}class L extends p{constructor(s){super(),g(this,s,K,H,$,{label:0})}}var W=L;const X=["static"];export{W as Component,X as modes};
