import{S as i,i as _,s as f,R as u,f as c,b as m,t as r,c as b,N as g,O as d,P as h,v as p,w,e as k}from"./index.f808f2eb.js";function y(n){let t,a;const o=n[2].default,s=u(o,n,n[1],null);return{c(){t=c("span"),s&&s.c(),m(t,"class","text-gray-600 text-[0.855rem] mb-2 block dark:text-gray-200"),r(t,"sr-only",!n[0])},m(e,l){b(e,t,l),s&&s.m(t,null),a=!0},p(e,[l]){s&&s.p&&(!a||l&2)&&g(s,o,e,e[1],a?h(o,e[1],l,null):d(e[1]),null),l&1&&r(t,"sr-only",!e[0])},i(e){a||(p(s,e),a=!0)},o(e){w(s,e),a=!1},d(e){e&&k(t),s&&s.d(e)}}}function B(n,t,a){let{$$slots:o={},$$scope:s}=t,{show_label:e=!0}=t;return n.$$set=l=>{"show_label"in l&&a(0,e=l.show_label),"$$scope"in l&&a(1,s=l.$$scope)},[e,s,o]}class q extends i{constructor(t){super(),_(this,t,B,y,f,{show_label:0})}}export{q as B};
