import{S as r,i as f,s as o,f as v,b as d,c as y,n as c,e as g,A as m,q as b,u as H,v as L,w as M,x as T,E as q}from"./index.f808f2eb.js";function w(a){let e;return{c(){e=v("div"),d(e,"class","output-html")},m(n,t){y(n,e,t),e.innerHTML=a[0]},p(n,[t]){t&1&&(e.innerHTML=n[0])},i:c,o:c,d(n){n&&g(e)}}}function C(a,e,n){let{value:t}=e,{style:l=""}=e;const s=m();return a.$$set=i=>{"value"in i&&n(0,t=i.value),"style"in i&&n(1,l=i.style)},a.$$.update=()=>{a.$$.dirty&1&&s("change")},[t,l]}class E extends r{constructor(e){super(),f(this,e,C,w,o,{value:0,style:1})}}function S(a){let e,n;return e=new E({props:{value:a[0],style:a[1]}}),e.$on("change",a[4]),{c(){b(e.$$.fragment)},m(t,l){H(e,t,l),n=!0},p(t,[l]){const s={};l&1&&(s.value=t[0]),l&2&&(s.style=t[1]),e.$set(s)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){T(e,t)}}}function x(a,e,n){let{label:t}=e,{value:l=""}=e,{default_value:s}=e,{style:i=""}=e;const _=m();s&&(l=s);function h(u){q.call(this,a,u)}return a.$$set=u=>{"label"in u&&n(2,t=u.label),"value"in u&&n(0,l=u.value),"default_value"in u&&n(3,s=u.default_value),"style"in u&&n(1,i=u.style)},a.$$.update=()=>{a.$$.dirty&4&&_("change")},[l,i,t,s,h]}class A extends r{constructor(e){super(),f(this,e,x,S,o,{label:2,value:0,default_value:3,style:1})}}var j=A;const k=["static"];export{j as Component,k as modes};
