import{S as c,i as _,s as m,R as h,f as k,b as r,c as b,l as z,N as B,O as q,P as w,v,w as g,e as d,E as y,q as C,u as S,x as j,J as E,X as J,h as N,j as O}from"./index.f808f2eb.js";function P(l){let t,a,e,s,f;const o=l[4].default,i=h(o,l,l[3],null);return{c(){t=k("button"),i&&i.c(),r(t,"style",l[1]),r(t,"class",a="gr-button gr-button-"+l[2]+" gr-button-"+l[0]+" self-start flex-1")},m(u,n){b(u,t,n),i&&i.m(t,null),e=!0,s||(f=z(t,"click",l[5]),s=!0)},p(u,[n]){i&&i.p&&(!e||n&8)&&B(i,o,u,u[3],e?w(o,u[3],n,null):q(u[3]),null),(!e||n&2)&&r(t,"style",u[1]),(!e||n&5&&a!==(a="gr-button gr-button-"+u[2]+" gr-button-"+u[0]+" self-start flex-1"))&&r(t,"class",a)},i(u){e||(v(i,u),e=!0)},o(u){g(i,u),e=!1},d(u){u&&d(t),i&&i.d(u),s=!1,f()}}}function R(l,t,a){let{$$slots:e={},$$scope:s}=t,{variant:f="secondary"}=t,{style:o=""}=t,{size:i="lg"}=t;function u(n){y.call(this,l,n)}return l.$$set=n=>{"variant"in n&&a(0,f=n.variant),"style"in n&&a(1,o=n.style),"size"in n&&a(2,i=n.size),"$$scope"in n&&a(3,s=n.$$scope)},[f,o,i,s,e,u]}class X extends c{constructor(t){super(),_(this,t,R,P,m,{variant:0,style:1,size:2})}}function A(l){let t=l[3](l[0])+"",a;return{c(){a=N(t)},m(e,s){b(e,a,s)},p(e,s){s&9&&t!==(t=e[3](e[0])+"")&&O(a,t)},d(e){e&&d(a)}}}function D(l){let t,a;return t=new X({props:{variant:l[2],style:l[1],$$slots:{default:[A]},$$scope:{ctx:l}}}),t.$on("click",l[5]),{c(){C(t.$$.fragment)},m(e,s){S(t,e,s),a=!0},p(e,[s]){const f={};s&4&&(f.variant=e[2]),s&2&&(f.style=e[1]),s&73&&(f.$$scope={dirty:s,ctx:e}),t.$set(f)},i(e){a||(v(t.$$.fragment,e),a=!0)},o(e){g(t.$$.fragment,e),a=!1},d(e){j(t,e)}}}function F(l,t,a){let e;E(l,J,n=>a(3,e=n));let{value:s}=t,{default_value:f=void 0}=t,{style:o=""}=t,{variant:i="primary"}=t;f&&(s=f);function u(n){y.call(this,l,n)}return l.$$set=n=>{"value"in n&&a(0,s=n.value),"default_value"in n&&a(4,f=n.default_value),"style"in n&&a(1,o=n.style),"variant"in n&&a(2,i=n.variant)},[s,o,i,e,f,u]}class G extends c{constructor(t){super(),_(this,t,F,D,m,{value:0,default_value:4,style:1,variant:2})}}var I=G;const K=["static"];export{I as Component,K as modes};
