import{S as l,i as r,s as o,f as c,h as d,b as u,c as f,d as m,j as p,n as i,e as v}from"./index.f808f2eb.js";function x(n){let e,s;return{c(){e=c("div"),s=d(n[0]),u(e,"class","gr-sample-3d")},m(a,t){f(a,e,t),m(e,s)},p(a,[t]){t&1&&p(s,a[0])},i,o:i,d(a){a&&v(e)}}}function _(n,e,s){let{value:a}=e;return n.$$set=t=>{"value"in t&&s(0,a=t.value)},[a]}class h extends l{constructor(e){super(),r(this,e,_,x,o,{value:0})}}var D=h;export{D as E};
