import{S as d,i as $,s as h,q as c,u as m,v as f,w as i,x as g,K as C,R as b,m as k,c as y,L as S,M as w,N as q,O as v,P as j,e as E,E as K}from"./index.f808f2eb.js";import{C as L}from"./CarouselItem.svelte_svelte_type_style_lang.b95c5ef5.js";import{S as M}from"./StatusTracker.9996b515.js";function N(n){let t,o,s;const r=[n[1]];let l={};for(let e=0;e<r.length;e+=1)l=C(l,r[e]);t=new M({props:l});const _=n[2].default,a=b(_,n,n[4],null);return{c(){c(t.$$.fragment),o=k(),a&&a.c()},m(e,u){m(t,e,u),y(e,o,u),a&&a.m(e,u),s=!0},p(e,u){const p=u&2?S(r,[w(e[1])]):{};t.$set(p),a&&a.p&&(!s||u&16)&&q(a,_,e,e[4],s?j(_,e[4],u,null):v(e[4]),null)},i(e){s||(f(t.$$.fragment,e),f(a,e),s=!0)},o(e){i(t.$$.fragment,e),i(a,e),s=!1},d(e){g(t,e),e&&E(o),a&&a.d(e)}}}function O(n){let t,o;return t=new L({props:{style:n[0],$$slots:{default:[N]},$$scope:{ctx:n}}}),t.$on("change",n[3]),{c(){c(t.$$.fragment)},m(s,r){m(t,s,r),o=!0},p(s,[r]){const l={};r&1&&(l.style=s[0]),r&18&&(l.$$scope={dirty:r,ctx:s}),t.$set(l)},i(s){o||(f(t.$$.fragment,s),o=!0)},o(s){i(t.$$.fragment,s),o=!1},d(s){g(t,s)}}}function P(n,t,o){let{$$slots:s={},$$scope:r}=t,{style:l=""}=t,{loading_status:_}=t;function a(e){K.call(this,n,e)}return n.$$set=e=>{"style"in e&&o(0,l=e.style),"loading_status"in e&&o(1,_=e.loading_status),"$$scope"in e&&o(4,r=e.$$scope)},[l,_,s,a,r]}class R extends d{constructor(t){super(),$(this,t,P,O,h,{style:0,loading_status:1})}}var B=R;const D=["static"];export{B as Component,D as modes};
