import{S as c,i as m,s as d,R as g,f as v,b as o,t as i,c as w,N as h,O as y,P as R,v as b,w as C,e as S}from"./index.f808f2eb.js";function q(f){let l,a;const u=f[5].default,t=g(u,f,f[4],null);return{c(){l=v("div"),t&&t.c(),o(l,"style",f[1]),o(l,"class","flex flex-col md:flex-row gr-gap gr-form-gap row w-full flex-none"),i(l,"hidden",!f[0]),i(l,"flex-1",f[2]==="row")},m(e,s){w(e,l,s),t&&t.m(l,null),a=!0},p(e,[s]){t&&t.p&&(!a||s&16)&&h(t,u,e,e[4],a?R(u,e[4],s,null):y(e[4]),null),(!a||s&2)&&o(l,"style",e[1]),s&1&&i(l,"hidden",!e[0]),s&4&&i(l,"flex-1",e[2]==="row")},i(e){a||(b(t,e),a=!0)},o(e){C(t,e),a=!1},d(e){e&&S(l),t&&t.d(e)}}}function N(f,l,a){let{$$slots:u={},$$scope:t}=l,{value:e}=l,{default_value:s}=l,{style:_=""}=l,{parent:r=null}=l;return s&&(e=s),f.$$set=n=>{"value"in n&&a(0,e=n.value),"default_value"in n&&a(3,s=n.default_value),"style"in n&&a(1,_=n.style),"parent"in n&&a(2,r=n.parent),"$$scope"in n&&a(4,t=n.$$scope)},[e,_,r,s,t,u]}class O extends c{constructor(l){super(),m(this,l,N,q,d,{value:0,default_value:3,style:1,parent:2})}}var j=O;const k=["static"];export{j as Component,k as modes};
