import{S as c,i as u,s as f,f as _,b as l,G as n,c as o,n as m,e as g}from"./index.f808f2eb.js";function d(i){let e,a;return{c(){e=_("img"),l(e,"class","gr-sample-image"),n(e.src,a=i[1]+i[0])||l(e,"src",a)},m(s,t){o(s,e,t)},p(s,[t]){t&3&&!n(e.src,a=s[1]+s[0])&&l(e,"src",a)},i:m,o:m,d(s){s&&g(e)}}}function v(i,e,a){let{value:s}=e,{samples_dir:t}=e;return i.$$set=r=>{"value"in r&&a(0,s=r.value),"samples_dir"in r&&a(1,t=r.samples_dir)},[s,t]}class p extends c{constructor(e){super(),u(this,e,v,d,f,{value:0,samples_dir:1})}}var q=p;export{q as E};
