import{S as K,i as O,s as w,f as S,b as u,t as d,c as h,N as q,O as E,P as L,v as y,w as B,e as C,k as P,Q,R,T}from"./index.f808f2eb.js";function g(o){let n,i,s;const t=o[11].default,l=R(t,o,o[10],null);return{c(){n=S(o[7]),l&&l.c(),u(n,"data-testid",o[4]),u(n,"class",i="gr-box overflow-hidden "+o[6][o[0]]+" "+o[6][o[1]]+" "+o[5]),d(n,"gr-panel",o[2]),d(n,"form",o[3]),d(n,"flex-1",o[8]==="row"||null)},m(e,a){h(e,n,a),l&&l.m(n,null),s=!0},p(e,a){l&&l.p&&(!s||a&1024)&&q(l,t,e,e[10],s?L(t,e[10],a,null):E(e[10]),null),(!s||a&16)&&u(n,"data-testid",e[4]),(!s||a&35&&i!==(i="gr-box overflow-hidden "+e[6][e[0]]+" "+e[6][e[1]]+" "+e[5]))&&u(n,"class",i),a&39&&d(n,"gr-panel",e[2]),a&43&&d(n,"form",e[3]),a&291&&d(n,"flex-1",e[8]==="row"||null)},i(e){s||(y(l,e),s=!0)},o(e){B(l,e),s=!1},d(e){e&&C(n),l&&l.d(e)}}}function Y(o){let n=o[7],i,s,t=o[7]&&g(o);return{c(){t&&t.c(),i=P()},m(l,e){t&&t.m(l,e),h(l,i,e),s=!0},p(l,[e]){l[7]?n?w(n,l[7])?(t.d(1),t=g(l),t.c(),t.m(i.parentNode,i)):t.p(l,e):(t=g(l),t.c(),t.m(i.parentNode,i)):n&&(t.d(1),t=null),n=l[7]},i(l){s||(y(t),s=!0)},o(l){B(t),s=!1},d(l){l&&C(i),t&&t.d(l)}}}function j(o,n,i){let s,{$$slots:t={},$$scope:l}=n,{variant:e="solid"}=n,{color:a="grey"}=n,{padding:b=!0}=n,{form_position:f=void 0}=n,{type:_="normal"}=n,{test_id:c=void 0}=n;const N={dashed:"border-dashed border-[3px]",solid:"border-solid border",grey:"border-gray-200",green:"border-green-400",none:"!border-0"},m={column:{first:"!rounded-b-none",last:"!rounded-t-none",mid:"!rounded-none",single:""},row:{first:"!rounded-r-none",last:"!rounded-l-none",mid:"!rounded-none",single:""}};let k=_==="fieldset"?"fieldset":"div";const v=Q(T);return o.$$set=r=>{"variant"in r&&i(0,e=r.variant),"color"in r&&i(1,a=r.color),"padding"in r&&i(2,b=r.padding),"form_position"in r&&i(3,f=r.form_position),"type"in r&&i(9,_=r.type),"test_id"in r&&i(4,c=r.test_id),"$$scope"in r&&i(10,l=r.$$scope)},o.$$.update=()=>{o.$$.dirty&8&&i(5,s=f?m==null?void 0:m[v||"column"][f]:"")},[e,a,b,f,c,s,N,k,v,_,l,t]}class A extends K{constructor(n){super(),O(this,n,j,Y,w,{variant:0,color:1,padding:2,form_position:3,type:9,test_id:4})}}export{A as B};
