import{S as c,i as o,s as f,f as v,b as h,Y as y,c as g,n as r,e as w,A as d,q as b,u as k,v as M,w as q,x,E as C}from"./index.f808f2eb.js";function E(a){let e;return{c(){e=v("div"),h(e,"class","output-markdown prose"),y(e,"max-width","100%")},m(n,t){g(n,e,t),e.innerHTML=a[0]},p(n,[t]){t&1&&(e.innerHTML=n[0])},i:r,o:r,d(n){n&&w(e)}}}function H(a,e,n){let{value:t}=e,{style:s=""}=e;const l=d();return a.$$set=u=>{"value"in u&&n(0,t=u.value),"style"in u&&n(1,s=u.style)},a.$$.update=()=>{a.$$.dirty&1&&l("change")},[t,s]}class L extends c{constructor(e){super(),o(this,e,H,E,f,{value:0,style:1})}}function S(a){let e,n;return e=new L({props:{value:a[0],style:a[1]}}),e.$on("change",a[4]),{c(){b(e.$$.fragment)},m(t,s){k(e,t,s),n=!0},p(t,[s]){const l={};s&1&&(l.value=t[0]),s&2&&(l.style=t[1]),e.$set(l)},i(t){n||(M(e.$$.fragment,t),n=!0)},o(t){q(e.$$.fragment,t),n=!1},d(t){x(e,t)}}}function T(a,e,n){let{label:t}=e,{value:s=""}=e,{default_value:l}=e,{style:u=""}=e;const m=d();l&&(s=l);function _(i){C.call(this,a,i)}return a.$$set=i=>{"label"in i&&n(2,t=i.label),"value"in i&&n(0,s=i.value),"default_value"in i&&n(3,l=i.default_value),"style"in i&&n(1,u=i.style)},a.$$.update=()=>{a.$$.dirty&4&&m("change")},[s,u,t,l,_]}class A extends c{constructor(e){super(),o(this,e,T,S,f,{label:2,value:0,default_value:3,style:1})}}var Y=A;const j=["static"];export{Y as Component,j as modes};
